window.Gleam.initSearch([{"doc":"lustre_animation","title":"lustre_animation","content":"# Lustre Animation\n\nThe basic usage is\n * keep 1 `Animations` value\n * add animations by some trigger\n * call `animation.cmd()` on your value and let your lustre `update()` return it.\n   This will cause a dispatch on the next JS animation frame, unless all animations have finished (and auto-removed)\n * update the animations with the new time.\n * evaluate for each animation you are interested in.\n\ne.g. like this:\n```gleam\nimport lustre/animation as a\n\npub type Msg {\n    Trigger\n    Tick(Float)\n}\n\npub fn update(model: Model, msg: Msg) {\n    let m = case msg of {\n        Trigger -&gt; {\n            let new_anim = a.add(model.animations, &quot;id&quot;, 1.0, 2.0, 0.250)\n            Model(1.0, animations: new_anim)\n        }\n        Tick(t) -&gt; {\n            let new_anim = a.tick(model.animations, t)\n            let new_value = a.value(new_anim, &quot;id&quot;, model.value)\n            Model(new_value, new_anim)\n        }\n    }\n    #(m, animation.cmd(m.animations, Tick))\n}\n```\n\nIn the above `type Model`, `init` and `render` have been omitted.\n\nThere are fully functional examples animations in the `test/` directory,\nwhich you can build by\n```bash\ngleam test\nnpx vite\n````\n\nand then pointing your browser to the URL that vite indicates.\n\n## TODO\n* `every(Minute)`, etc\n* quadratic, cubic, etc interpolators\n* Compose animations\n  `from(&quot;anim&quot;, 1.0) |&gt; after(0.250) |&gt; cubic(3.0, 0.250) |&gt; after(0.250) |&gt; quadr(2.0, 0.250)`","url":"index.html"},{"doc":"lustre/animation","title":"Animations","content":"pub opaque type Animations\n A singleton holding all your animations, and a timestamp\n\nSynonyms:\nlustre/animation.Animations\nlustre/animation Animations","url":"lustre/animation.html#Animations"},{"doc":"lustre/animation","title":"RequestedFrame","content":"pub type RequestedFrame\n\n\nSynonyms:\nlustre/animation.RequestedFrame\nlustre/animation RequestedFrame","url":"lustre/animation.html#RequestedFrame"},{"doc":"lustre/animation","title":"TimeoutId","content":"pub type TimeoutId\n\n\nSynonyms:\nlustre/animation.TimeoutId\nlustre/animation TimeoutId","url":"lustre/animation.html#TimeoutId"},{"doc":"lustre/animation","title":"add","content":"pub fn add(animations: Animations, name: String, start: Float, stop: Float, seconds: Float) -&gt; Animations\n Add an animation (linear interpolation) from `start` to `stop`, for `seconds` duration.\n The `name` should be unique, so the animation can be retrieved and evaluated by `value()` later.\n The animation is started when a subsequent command from `effect()` is returned by your\n lustre `update()` function; followed by a call to `tick()`.\nSynonyms:\nlustre/animation.add\nlustre/animation add","url":"lustre/animation.html#add"},{"doc":"lustre/animation","title":"after","content":"pub fn after(ms: Float, msg_after: fn(TimeoutId) -&gt; a, msg_bell: a) -&gt; Effect(\n  a,\n)\n\nSynonyms:\nlustre/animation.after\nlustre/animation after","url":"lustre/animation.html#after"},{"doc":"lustre/animation","title":"cancel","content":"pub fn cancel(timeout_id: TimeoutId) -&gt; Effect(a)\n\nSynonyms:\nlustre/animation.cancel\nlustre/animation cancel","url":"lustre/animation.html#cancel"},{"doc":"lustre/animation","title":"effect","content":"pub fn effect(animations: Animations, msg: fn(Float) -&gt; a) -&gt; Effect(\n  a,\n)\n Returns `effect.none()` if none of the animations is running.\n Otherwise returns an opaque `Effect` that will cause `msg(time)` to\n be dispatched on a JavaScript `requestAnimationFrame`\nSynonyms:\nlustre/animation.effect\nlustre/animation effect","url":"lustre/animation.html#effect"},{"doc":"lustre/animation","title":"new","content":"pub fn new() -&gt; Animations\n\nSynonyms:\nlustre/animation.new\nlustre/animation new","url":"lustre/animation.html#new"},{"doc":"lustre/animation","title":"remove","content":"pub fn remove(animations: Animations, name: String) -&gt; Animations\n Remove an animation if it should stop before it is finished.\n If an animation runs to its end normally, you do not have to `remove()` it manually,\n will be automatically removed by `tick()`.\nSynonyms:\nlustre/animation.remove\nlustre/animation remove","url":"lustre/animation.html#remove"},{"doc":"lustre/animation","title":"request_animation_frame","content":"pub fn request_animation_frame(msg: fn(Float) -&gt; a) -&gt; Effect(a)\n\nSynonyms:\nlustre/animation.request_animation_frame\nlustre/animation request_animation_frame","url":"lustre/animation.html#request_animation_frame"},{"doc":"lustre/animation","title":"tick","content":"pub fn tick(animations: Animations, time_offset: Float) -&gt; Animations\n When called for the first time on an animation, its start time is\n set to time-Offset. Its stop time then is the start time plus the\n duration.\n\n When called for the *first* time for animations that have finished,\n they will be marked as such in the result. `value()` will return the `stop` value\n that you passed with `add()`\n\n When called the *second* time for animations that have finished, they will be absent\n from the returned value.\nSynonyms:\nlustre/animation.tick\nlustre/animation tick","url":"lustre/animation.html#tick"},{"doc":"lustre/animation","title":"value","content":"pub fn value(animations: Animations, which: String, default: Float) -&gt; Float\n If the animation specified by `which` is not found, returns `default`.\n Otherwise, the interpolated value for the `time` passed to `tick()` is returned.\nSynonyms:\nlustre/animation.value\nlustre/animation value","url":"lustre/animation.html#value"},{"doc":"lustre/animation","title":"lustre/animation","content":"","url":"lustre/animation.html"}]);